==> sdk-3.2.3-sources.jar: com/kontakt/sdk/android/ble/manager/EventObserver.java <==
package com.kontakt.sdk.android.ble.manager;

import android.os.Handler;

import com.kontakt.sdk.android.ble.discovery.BluetoothDeviceEvent;
import com.kontakt.sdk.android.ble.discovery.eddystone.EddystoneDeviceEvent;
import com.kontakt.sdk.android.ble.discovery.ibeacon.IBeaconDeviceEvent;
import com.kontakt.sdk.android.ble.discovery.secure_profile.SecureProfileEvent;
import com.kontakt.sdk.android.ble.exception.ScanError;
import com.kontakt.sdk.android.ble.manager.listeners.EddystoneListener;
import com.kontakt.sdk.android.ble.manager.listeners.IBeaconListener;
import com.kontakt.sdk.android.ble.manager.listeners.InternalProximityListener;
import com.kontakt.sdk.android.ble.manager.listeners.ScanStatusListener;
import com.kontakt.sdk.android.ble.manager.listeners.SecureProfileListener;
import com.kontakt.sdk.android.ble.manager.listeners.SpaceListener;
import com.kontakt.sdk.android.common.profile.IBeaconDevice;
import com.kontakt.sdk.android.common.profile.IEddystoneDevice;

import java.util.List;

/**
 * Simple class that helps with invoking proper callbacks based on {@link BluetoothDeviceEvent} type.
 */
@SuppressWarnings("WeakerAccess")
class EventObserver implements InternalProximityListener {

  private final Handler handler = new Handler(); //Handler ensures that final callbacks are received on the same thread.

  final ScanStatusListener scanStatusListener;
  final SpaceListener spaceListener;
  final EddystoneListener eddystoneListener;
  final IBeaconListener iBeaconListener;
  final SecureProfileListener secureProfileListener;

  EventObserver(EddystoneListener eddystoneListener, IBeaconListener iBeaconListener, ScanStatusListener scanStatusListener,
      SpaceListener spaceListener, SecureProfileListener secureProfileListener) {
    this.iBeaconListener = iBeaconListener;
    this.eddystoneListener = eddystoneListener;
    this.scanStatusListener = scanStatusListener;
    this.spaceListener = spaceListener;
    this.secureProfileListener = secureProfileListener;
  }

  @Override
  public void onScanStart() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onScanStart();
        }
      }
    });
  }

  @Override
  public void onScanStop() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onScanStop();
        }
      }
    });
  }

  @Override
  public void onMonitoringCycleStart() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onMonitoringCycleStart();
        }
      }
    });
  }

  @Override
  public void onMonitoringCycleStop() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onMonitoringCycleStop();
        }
      }
    });
  }

  @Override
  public void onScanError(final ScanError exception) {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onScanError(exception);
        }
      }
    });
  }

  @Override
  public void onEvent(final BluetoothDeviceEvent event) {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (eddystoneListener != null && event instanceof EddystoneDeviceEvent) {
          onEddystoneEvent((EddystoneDeviceEvent) event);
        } else if (iBeaconListener != null && event instanceof IBeaconDeviceEvent) {
          onIBeaconEvent((IBeaconDeviceEvent) event);
        } else if (secureProfileListener != null && event instanceof SecureProfileEvent) {
          onSecureProfileEvent((SecureProfileEvent) event);
        }
      }
    });
  }

  void onEddystoneEvent(EddystoneDeviceEvent event) {
    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
      case DEVICES_UPDATE:
      case DEVICE_LOST:
        invokeDeviceCallbacks(event);
        break;
      case SPACE_ENTERED:
      case SPACE_ABANDONED:
        invokeSpaceCallbacks(event);
        break;
    }
  }

  void onIBeaconEvent(IBeaconDeviceEvent event) {
    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
      case DEVICES_UPDATE:
      case DEVICE_LOST:
        invokeDeviceCallbacks(event);
        break;
      case SPACE_ENTERED:
      case SPACE_ABANDONED:
        invokeSpaceCallbacks(event);
        break;
    }
  }

  void onSecureProfileEvent(SecureProfileEvent event) {
    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
        secureProfileListener.onProfileDiscovered(event.getSecureProfileDevices().get(0));
        break;
      case DEVICES_UPDATE:
        secureProfileListener.onProfilesUpdated(event.getSecureProfileDevices());
        break;
      case DEVICE_LOST:
        secureProfileListener.onProfileLost(event.getSecureProfileDevices().get(0));
        break;
    }
  }

  private void invokeDeviceCallbacks(EddystoneDeviceEvent event) {
    List<IEddystoneDevice> deviceList = event.getDeviceList();
    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
        eddystoneListener.onEddystoneDiscovered(deviceList.get(0), event.getNamespace());
        break;
      case DEVICES_UPDATE:
        eddystoneListener.onEddystonesUpdated(deviceList, event.getNamespace());
        break;
      case DEVICE_LOST:
        eddystoneListener.onEddystoneLost(deviceList.get(0), event.getNamespace());
        break;
    }
  }

  private void invokeDeviceCallbacks(IBeaconDeviceEvent event) {
    List<IBeaconDevice> deviceList = event.getDeviceList();
    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
        iBeaconListener.onIBeaconDiscovered(deviceList.get(0), event.getRegion());
        break;
      case DEVICES_UPDATE:
        iBeaconListener.onIBeaconsUpdated(deviceList, event.getRegion());
        break;
      case DEVICE_LOST:
        iBeaconListener.onIBeaconLost(deviceList.get(0), event.getRegion());
        break;
    }
  }

  private void invokeSpaceCallbacks(EddystoneDeviceEvent event) {
    if (spaceListener == null) {
      return;
    }
    switch (event.getEventType()) {
      case SPACE_ENTERED:
        spaceListener.onNamespaceEntered(event.getNamespace());
        break;
      case SPACE_ABANDONED:
        spaceListener.onNamespaceAbandoned(event.getNamespace());
        break;
    }
  }

  private void invokeSpaceCallbacks(IBeaconDeviceEvent event) {
    if (spaceListener == null) {
      return;
    }
    switch (event.getEventType()) {
      case SPACE_ENTERED:
        spaceListener.onRegionEntered(event.getRegion());
        break;
      case SPACE_ABANDONED:
        spaceListener.onRegionAbandoned(event.getRegion());
        break;
    }
  }
}

==> sdk-3.3.1-sources.jar: com/kontakt/sdk/android/ble/manager/EventObserver.java <==
package com.kontakt.sdk.android.ble.manager;

import android.os.Handler;

import com.kontakt.sdk.android.ble.discovery.BluetoothDeviceEvent;
import com.kontakt.sdk.android.ble.discovery.eddystone.EddystoneDeviceEvent;
import com.kontakt.sdk.android.ble.discovery.ibeacon.IBeaconDeviceEvent;
import com.kontakt.sdk.android.ble.discovery.secure_profile.SecureProfileEvent;
import com.kontakt.sdk.android.ble.exception.ScanError;
import com.kontakt.sdk.android.ble.manager.listeners.EddystoneListener;
import com.kontakt.sdk.android.ble.manager.listeners.IBeaconListener;
import com.kontakt.sdk.android.ble.manager.listeners.InternalProximityListener;
import com.kontakt.sdk.android.ble.manager.listeners.ScanStatusListener;
import com.kontakt.sdk.android.ble.manager.listeners.SecureProfileListener;
import com.kontakt.sdk.android.ble.manager.listeners.SpaceListener;
import com.kontakt.sdk.android.common.profile.IBeaconDevice;
import com.kontakt.sdk.android.common.profile.IEddystoneDevice;

import java.util.List;

/**
 * Simple class that helps with invoking proper callbacks based on {@link BluetoothDeviceEvent} type.
 */
@SuppressWarnings("WeakerAccess")
class EventObserver implements InternalProximityListener {

  private final Handler handler = new Handler(); //Handler ensures that final callbacks are received on the same thread.

  final ScanStatusListener scanStatusListener;
  final SpaceListener spaceListener;
  final EddystoneListener eddystoneListener;
  final IBeaconListener iBeaconListener;
  final SecureProfileListener secureProfileListener;

  EventObserver(EddystoneListener eddystoneListener, IBeaconListener iBeaconListener, ScanStatusListener scanStatusListener,
                SpaceListener spaceListener, SecureProfileListener secureProfileListener) {
    this.iBeaconListener = iBeaconListener;
    this.eddystoneListener = eddystoneListener;
    this.scanStatusListener = scanStatusListener;
    this.spaceListener = spaceListener;
    this.secureProfileListener = secureProfileListener;
  }

  @Override
  public void onScanStart() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onScanStart();
        }
      }
    });
  }

  @Override
  public void onScanStop() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onScanStop();
        }
      }
    });
  }

  @Override
  public void onMonitoringCycleStart() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onMonitoringCycleStart();
        }
      }
    });
  }

  @Override
  public void onMonitoringCycleStop() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onMonitoringCycleStop();
        }
      }
    });
  }

  @Override
  public void onScanError(final ScanError exception) {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (scanStatusListener != null) {
          scanStatusListener.onScanError(exception);
        }
      }
    });
  }

  @Override
  public void onEvent(final BluetoothDeviceEvent event) {
    handler.post(new Runnable() {
      @Override
      public void run() {
        if (event instanceof EddystoneDeviceEvent) {
          onEddystoneEvent((EddystoneDeviceEvent) event);
        } else if (event instanceof IBeaconDeviceEvent) {
          onIBeaconEvent((IBeaconDeviceEvent) event);
        } else if (event instanceof SecureProfileEvent) {
          onSecureProfileEvent((SecureProfileEvent) event);
        }
      }
    });
  }

  void onEddystoneEvent(EddystoneDeviceEvent event) {
    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
      case DEVICES_UPDATE:
      case DEVICE_LOST:
        invokeDeviceCallbacks(event);
        break;
      case SPACE_ENTERED:
      case SPACE_ABANDONED:
        invokeSpaceCallbacks(event);
        break;
    }
  }

  void onIBeaconEvent(IBeaconDeviceEvent event) {
    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
      case DEVICES_UPDATE:
      case DEVICE_LOST:
        invokeDeviceCallbacks(event);
        break;
      case SPACE_ENTERED:
      case SPACE_ABANDONED:
        invokeSpaceCallbacks(event);
        break;
    }
  }

  void onSecureProfileEvent(SecureProfileEvent event) {
    if (secureProfileListener == null) {
      return;
    }

    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
        secureProfileListener.onProfileDiscovered(event.getSecureProfileDevices().get(0));
        break;
      case DEVICES_UPDATE:
        secureProfileListener.onProfilesUpdated(event.getSecureProfileDevices());
        break;
      case DEVICE_LOST:
        secureProfileListener.onProfileLost(event.getSecureProfileDevices().get(0));
        break;
    }
  }

  private void invokeDeviceCallbacks(EddystoneDeviceEvent event) {
    if (eddystoneListener == null) {
      return;
    }

    List<IEddystoneDevice> deviceList = event.getDeviceList();
    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
        eddystoneListener.onEddystoneDiscovered(deviceList.get(0), event.getNamespace());
        break;
      case DEVICES_UPDATE:
        eddystoneListener.onEddystonesUpdated(deviceList, event.getNamespace());
        break;
      case DEVICE_LOST:
        eddystoneListener.onEddystoneLost(deviceList.get(0), event.getNamespace());
        break;
    }
  }

  private void invokeDeviceCallbacks(IBeaconDeviceEvent event) {
    if (iBeaconListener == null) {
      return;
    }

    List<IBeaconDevice> deviceList = event.getDeviceList();
    switch (event.getEventType()) {
      case DEVICE_DISCOVERED:
        iBeaconListener.onIBeaconDiscovered(deviceList.get(0), event.getRegion());
        break;
      case DEVICES_UPDATE:
        iBeaconListener.onIBeaconsUpdated(deviceList, event.getRegion());
        break;
      case DEVICE_LOST:
        iBeaconListener.onIBeaconLost(deviceList.get(0), event.getRegion());
        break;
    }
  }

  private void invokeSpaceCallbacks(EddystoneDeviceEvent event) {
    if (spaceListener == null) {
      return;
    }

    switch (event.getEventType()) {
      case SPACE_ENTERED:
        spaceListener.onNamespaceEntered(event.getNamespace());
        break;
      case SPACE_ABANDONED:
        spaceListener.onNamespaceAbandoned(event.getNamespace());
        break;
    }
  }

  private void invokeSpaceCallbacks(IBeaconDeviceEvent event) {
    if (spaceListener == null) {
      return;
    }

    switch (event.getEventType()) {
      case SPACE_ENTERED:
        spaceListener.onRegionEntered(event.getRegion());
        break;
      case SPACE_ABANDONED:
        spaceListener.onRegionAbandoned(event.getRegion());
        break;
    }
  }
}
